Mouse provider implementation — Kivy v1.0.1-dev documentation

# Mouse provider implementation

On linux system, mouse provider can be annoying when used with another multitouch provider (hidinput or mtdev.). Mouse can conflict with them: a single touch can generate one event from mouse provider and from multitouch provider.

To avoid this behavior, you can activate the “disable_on_activity” token in mouse. Then, if they are any touch active from another provider, the mouse will be discarded. Put in your configuration

    [input]
    mouse = mouse,disable_on_activity